==> haskell-cassava-0.4.5.1-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cassava.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava
version: 0.4.5.1
id: cassava-0.4.5.1-H9nLqKhX2xt9DqO4m3roDa
key: cassava-0.4.5.1-H9nLqKhX2xt9DqO4m3roDa
license: BSD3
copyright: (c) 2012 Johan Tibell
           (c) 2012 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/cassava
synopsis: A CSV parsing and encoding library
description:
    A CSV parsing and encoding library optimized for ease of use and high
    performance.
category: Text, Web, CSV
author: Johan Tibell
exposed: True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming
hidden-modules: Data.Csv.Conversion Data.Csv.Conversion.Internal
                Data.Csv.Encoding Data.Csv.Types Data.Csv.Util
abi: af26cd71ed672dde9da9bb623a9cf283
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cassava-0.4.5.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cassava-0.4.5.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/cassava-0.4.5.1
hs-libraries: HScassava-0.4.5.1-H9nLqKhX2xt9DqO4m3roDa
depends:
    array-0.5.1.1 attoparsec-0.13.1.0-A4pUaeqQWkyDZOYwXw4PvN
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html: /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-0.4.5.1-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cassava.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava
version: 0.4.5.1
id: cassava-0.4.5.1-8faj8wdL6ij4G3dkxsCmTR
key: cassava-0.4.5.1-8faj8wdL6ij4G3dkxsCmTR
license: BSD3
copyright: (c) 2012 Johan Tibell
           (c) 2012 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/cassava
synopsis: A CSV parsing and encoding library
description:
    A CSV parsing and encoding library optimized for ease of use and high
    performance.
category: Text, Web, CSV
author: Johan Tibell
exposed: True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming
hidden-modules: Data.Csv.Conversion Data.Csv.Conversion.Internal
                Data.Csv.Encoding Data.Csv.Types Data.Csv.Util
abi: 0f7233b078da47dc9bc0ebedf13e30f7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cassava-0.4.5.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cassava-0.4.5.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/cassava-0.4.5.1
hs-libraries: HScassava-0.4.5.1-8faj8wdL6ij4G3dkxsCmTR
depends:
    array-0.5.1.1 attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html: /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
